@@ -12,7 +12,7 @@
 # License for the specific language governing permissions and limitations
 # under the License.
 from supertokens_python.recipe.jwt.interfaces import APIInterface, APIOptions
-from supertokens_python.utils import send_200_response
+from supertokens_python.utils import default_user_context, send_200_response
 
 from ..interfaces import JWKSGetResponse
 
@@ -20,8 +20,9 @@ from ..interfaces import JWKSGetResponse
 async def jwks_get(api_implementation: APIInterface, api_options: APIOptions):
     if api_implementation.disable_jwks_get:
         return None
+    user_context = default_user_context(api_options.request)
 
-    result = await api_implementation.jwks_get(api_options, {})
+    result = await api_implementation.jwks_get(api_options, user_context)
     if isinstance(result, JWKSGetResponse):
         api_options.response.set_header("Access-Control-Allow-Origin", "*")
     return send_200_response(result.to_json(), api_options.response)
