@@ -13,25 +13,25 @@
 # under the License.
 import asyncio
 import json
-from typing import Any, Dict, Union
+from typing import Any, Dict, Union, Optional
 
 from fastapi import FastAPI
 from fastapi.requests import Request
 from fastapi.testclient import TestClient
 from pytest import fixture, mark, skip
 from supertokens_python import InputAppInfo, SupertokensConfig, init
+from supertokens_python.asyncio import delete_user
 from supertokens_python.exceptions import BadInputError
 from supertokens_python.framework.fastapi import get_middleware
 from supertokens_python.querier import Querier
-from supertokens_python.recipe import emailpassword, session
-from supertokens_python.recipe.emailpassword.asyncio import (
+from supertokens_python.recipe import emailpassword, session, emailverification
+from supertokens_python.recipe.emailverification.asyncio import (
     create_email_verification_token,
     is_email_verified,
-    revoke_email_verification_token,
+    revoke_email_verification_tokens,
     unverify_email,
     verify_email_using_token,
 )
-from supertokens_python.recipe.emailpassword.types import User
 from supertokens_python.recipe.emailverification.interfaces import (
     APIInterface,
     APIOptions,
@@ -40,36 +40,33 @@ from supertokens_python.recipe.emailverification.interfaces import (
     VerifyEmailUsingTokenInvalidTokenError,
 )
 from supertokens_python.recipe.emailverification.types import User as EVUser
-from supertokens_python.recipe.emailverification.utils import OverrideConfig
+from supertokens_python.recipe.emailverification.utils import (
+    OverrideConfig,
+)
 from supertokens_python.recipe.session import SessionContainer
 from supertokens_python.recipe.session.asyncio import (
     create_new_session,
     get_session,
     refresh_session,
 )
+from supertokens_python.recipe.session.constants import ANTI_CSRF_HEADER_KEY
 from supertokens_python.utils import is_version_gte
+from tests.utils import get_st_init_args, min_api_version
 from tests.utils import (
     TEST_ACCESS_TOKEN_MAX_AGE_CONFIG_KEY,
-    clean_st,
     email_verify_token_request,
     extract_all_cookies,
-    reset,
     set_key_value_in_config,
-    setup_st,
     sign_up_request,
     start_st,
+    setup_function,
+    teardown_function,
 )
 
+_ = setup_function  # type: ignore
+_ = teardown_function  # type: ignore
 
-def setup_function(_):
-    reset()
-    clean_st()
-    setup_st()
-
-
-def teardown_function(_):
-    reset()
-    clean_st()
+pytestmark = mark.asyncio
 
 
 @fixture(scope="function")
@@ -119,7 +116,6 @@ async def driver_config_client():
     return TestClient(app)
 
 
-@mark.asyncio
 async def test_the_generate_token_api_with_valid_input_email_not_verified(
     driver_config_client: TestClient,
 ):
@@ -132,7 +128,11 @@ async def test_the_generate_token_api_with_valid_input_email_not_verified(
             api_base_path="/auth",
         ),
         framework="fastapi",
-        recipe_list=[session.init(anti_csrf="VIA_TOKEN"), emailpassword.init()],
+        recipe_list=[
+            session.init(anti_csrf="VIA_TOKEN"),
+            emailverification.init("OPTIONAL"),
+            emailpassword.init(),
+        ],
     )
     start_st()
 
@@ -156,7 +156,6 @@ async def test_the_generate_token_api_with_valid_input_email_not_verified(
     assert dict_response["status"] == "OK"
 
 
-@mark.asyncio
 async def test_the_generate_token_api_with_valid_input_email_verified_and_test_error(
     driver_config_client: TestClient,
 ):
@@ -169,7 +168,11 @@ async def test_the_generate_token_api_with_valid_input_email_verified_and_test_e
             api_base_path="/auth",
         ),
         framework="fastapi",
-        recipe_list=[session.init(anti_csrf="VIA_TOKEN"), emailpassword.init()],
+        recipe_list=[
+            session.init(anti_csrf="VIA_TOKEN"),
+            emailverification.init("OPTIONAL"),
+            emailpassword.init(),
+        ],
     )
     start_st()
 
@@ -199,7 +202,6 @@ async def test_the_generate_token_api_with_valid_input_email_verified_and_test_e
     raise Exception("Test failed")
 
 
-@mark.asyncio
 async def test_the_generate_token_api_with_valid_input_no_session_and_check_output(
     driver_config_client: TestClient,
 ):
@@ -212,7 +214,11 @@ async def test_the_generate_token_api_with_valid_input_no_session_and_check_outp
             api_base_path="/auth",
         ),
         framework="fastapi",
-        recipe_list=[session.init(anti_csrf="VIA_TOKEN"), emailpassword.init()],
+        recipe_list=[
+            session.init(anti_csrf="VIA_TOKEN"),
+            emailverification.init("OPTIONAL"),
+            emailpassword.init(),
+        ],
     )
     start_st()
 
@@ -222,7 +228,6 @@ async def test_the_generate_token_api_with_valid_input_no_session_and_check_outp
     assert dict_response["message"] == "unauthorised"
 
 
-@mark.asyncio
 async def test_the_generate_token_api_with_an_expired_access_token_and_see_that_try_refresh_token_is_returned(
     driver_config_client: TestClient,
 ):
@@ -237,7 +242,11 @@ async def test_the_generate_token_api_with_an_expired_access_token_and_see_that_
             api_base_path="/auth",
         ),
         framework="fastapi",
-        recipe_list=[session.init(anti_csrf="VIA_TOKEN"), emailpassword.init()],
+        recipe_list=[
+            session.init(anti_csrf="VIA_TOKEN"),
+            emailverification.init("OPTIONAL"),
+            emailpassword.init(),
+        ],
     )
     start_st()
 
@@ -292,15 +301,14 @@ async def test_the_generate_token_api_with_an_expired_access_token_and_see_that_
     assert dict_response["status"] == "OK"
 
 
-@mark.asyncio
 async def test_that_providing_your_own_email_callback_and_make_sure_it_is_called(
     driver_config_client: TestClient,
 ):
-    user_info: Union[None, User] = None
+    user_info: Union[None, EVUser] = None
     email_token = None
 
     async def custom_f(
-        user: User, email_verification_url_token: str, _: Dict[str, Any]
+        user: EVUser, email_verification_url_token: str, _: Dict[str, Any]
     ):
         nonlocal user_info, email_token
         user_info = user
@@ -317,11 +325,10 @@ async def test_that_providing_your_own_email_callback_and_make_sure_it_is_called
         framework="fastapi",
         recipe_list=[
             session.init(anti_csrf="VIA_TOKEN"),
-            emailpassword.init(
-                email_verification_feature=emailpassword.InputEmailVerificationConfig(
-                    create_and_send_custom_email=custom_f
-                )
+            emailverification.init(
+                mode="REQUIRED", create_and_send_custom_email=custom_f
             ),
+            emailpassword.init(),
         ],
     )
     start_st()
@@ -353,11 +360,12 @@ async def test_that_providing_your_own_email_callback_and_make_sure_it_is_called
     assert email_token is not None
 
 
-@mark.asyncio
 async def test_the_email_verify_api_with_valid_input(driver_config_client: TestClient):
     token = None
 
-    async def custom_f(_: User, email_verification_url_token: str, __: Dict[str, Any]):
+    async def custom_f(
+        _: EVUser, email_verification_url_token: str, __: Dict[str, Any]
+    ):
         nonlocal token
         token = email_verification_url_token.split("?token=")[1].split("&rid=")[0]
 
@@ -372,11 +380,10 @@ async def test_the_email_verify_api_with_valid_input(driver_config_client: TestC
         framework="fastapi",
         recipe_list=[
             session.init(anti_csrf="VIA_TOKEN"),
-            emailpassword.init(
-                email_verification_feature=emailpassword.InputEmailVerificationConfig(
-                    create_and_send_custom_email=custom_f
-                )
+            emailverification.init(
+                mode="REQUIRED", create_and_send_custom_email=custom_f
             ),
+            emailpassword.init(),
         ],
     )
     start_st()
@@ -421,13 +428,14 @@ async def test_the_email_verify_api_with_valid_input(driver_config_client: TestC
     assert dict_response["status"] == "OK"
 
 
-@mark.asyncio
 async def test_the_email_verify_api_with_invalid_token_and_check_error(
     driver_config_client: TestClient,
 ):
     token = None
 
-    async def custom_f(_: User, email_verification_url_token: str, __: Dict[str, Any]):
+    async def custom_f(
+        _: EVUser, email_verification_url_token: str, __: Dict[str, Any]
+    ):
         nonlocal token
         token = email_verification_url_token.split("?token=")[1].split("&rid=")[0]
 
@@ -442,11 +450,10 @@ async def test_the_email_verify_api_with_invalid_token_and_check_error(
         framework="fastapi",
         recipe_list=[
             session.init(anti_csrf="VIA_TOKEN"),
-            emailpassword.init(
-                email_verification_feature=emailpassword.InputEmailVerificationConfig(
-                    create_and_send_custom_email=custom_f
-                )
+            emailverification.init(
+                mode="REQUIRED", create_and_send_custom_email=custom_f
             ),
+            emailpassword.init(),
         ],
     )
     start_st()
@@ -491,13 +498,14 @@ async def test_the_email_verify_api_with_invalid_token_and_check_error(
     assert dict_response["status"] == "EMAIL_VERIFICATION_INVALID_TOKEN_ERROR"
 
 
-@mark.asyncio
 async def test_the_email_verify_api_with_token_of_not_type_string(
     driver_config_client: TestClient,
 ):
     token = None
 
-    async def custom_f(_: User, email_verification_url_token: str, __: Dict[str, Any]):
+    async def custom_f(
+        _: EVUser, email_verification_url_token: str, __: Dict[str, Any]
+    ):
         nonlocal token
         token = email_verification_url_token.split("?token=")[1].split("&rid=")[0]
 
@@ -512,11 +520,10 @@ async def test_the_email_verify_api_with_token_of_not_type_string(
         framework="fastapi",
         recipe_list=[
             session.init(anti_csrf="VIA_TOKEN"),
-            emailpassword.init(
-                email_verification_feature=emailpassword.InputEmailVerificationConfig(
-                    create_and_send_custom_email=custom_f
-                )
+            emailverification.init(
+                mode="REQUIRED", create_and_send_custom_email=custom_f
             ),
+            emailpassword.init(),
         ],
     )
     start_st()
@@ -562,14 +569,15 @@ async def test_the_email_verify_api_with_token_of_not_type_string(
     assert dict_response["message"] == "The email verification token must be a string"
 
 
-@mark.asyncio
 async def test_that_the_handle_post_email_verification_callback_is_called_on_successful_verification_if_given(
     driver_config_client: TestClient,
 ):
     token = None
     user_info_from_callback: Union[None, EVUser] = None
 
-    async def custom_f(_: User, email_verification_url_token: str, __: Dict[str, Any]):
+    async def custom_f(
+        _: EVUser, email_verification_url_token: str, __: Dict[str, Any]
+    ):
         nonlocal token
         token = email_verification_url_token.split("?token=")[1].split("&rid=")[0]
 
@@ -577,11 +585,14 @@ async def test_that_the_handle_post_email_verification_callback_is_called_on_suc
         temp = param.email_verify_post
 
         async def email_verify_post(
-            token: str, api_options: APIOptions, user_context: Dict[str, Any]
+            token: str,
+            session: Optional[SessionContainer],
+            api_options: APIOptions,
+            user_context: Dict[str, Any],
         ):
             nonlocal user_info_from_callback
 
-            response = await temp(token, api_options, user_context)
+            response = await temp(token, session, api_options, user_context)
 
             if isinstance(response, EmailVerifyPostOkResult):
                 user_info_from_callback = response.user
@@ -602,16 +613,12 @@ async def test_that_the_handle_post_email_verification_callback_is_called_on_suc
         framework="fastapi",
         recipe_list=[
             session.init(anti_csrf="VIA_TOKEN"),
-            emailpassword.init(
-                email_verification_feature=emailpassword.InputEmailVerificationConfig(
-                    create_and_send_custom_email=custom_f
-                ),
-                override=emailpassword.InputOverrideConfig(
-                    email_verification_feature=OverrideConfig(
-                        apis=apis_override_email_password
-                    )
-                ),
+            emailverification.init(
+                mode="REQUIRED",
+                create_and_send_custom_email=custom_f,
+                override=OverrideConfig(apis=apis_override_email_password),
             ),
+            emailpassword.init(),
         ],
     )
     start_st()
@@ -663,13 +670,14 @@ async def test_that_the_handle_post_email_verification_callback_is_called_on_suc
     assert user_info_from_callback.email == "test@gmail.com"  # type: ignore
 
 
-@mark.asyncio
 async def test_the_email_verify_with_valid_input_using_the_get_method(
     driver_config_client: TestClient,
 ):
     token = None
 
-    async def custom_f(_: User, email_verification_url_token: str, __: Dict[str, Any]):
+    async def custom_f(
+        _: EVUser, email_verification_url_token: str, __: Dict[str, Any]
+    ):
         nonlocal token
         token = email_verification_url_token.split("?token=")[1].split("&rid=")[0]
 
@@ -684,11 +692,11 @@ async def test_the_email_verify_with_valid_input_using_the_get_method(
         framework="fastapi",
         recipe_list=[
             session.init(anti_csrf="VIA_TOKEN"),
-            emailpassword.init(
-                email_verification_feature=emailpassword.InputEmailVerificationConfig(
-                    create_and_send_custom_email=custom_f
-                )
+            emailverification.init(
+                mode="REQUIRED",
+                create_and_send_custom_email=custom_f,
             ),
+            emailpassword.init(),
         ],
     )
     start_st()
@@ -717,7 +725,9 @@ async def test_the_email_verify_with_valid_input_using_the_get_method(
     assert token is not None
 
     response_3 = driver_config_client.post(
-        url="/auth/user/email/verify", json={"method": "token", "token": token}
+        url="/auth/user/email/verify",
+        json={"method": "token", "token": token},
+        headers={ANTI_CSRF_HEADER_KEY: response_1.headers.get("anti-csrf")},
     )
 
     dict_response = json.loads(response_3.text)
@@ -741,7 +751,6 @@ async def test_the_email_verify_with_valid_input_using_the_get_method(
     assert dict_response["status"] == "OK"
 
 
-@mark.asyncio
 async def test_the_email_verify_with_no_session_using_the_get_method(
     driver_config_client: TestClient,
 ):
@@ -754,7 +763,11 @@ async def test_the_email_verify_with_no_session_using_the_get_method(
             api_base_path="/auth",
         ),
         framework="fastapi",
-        recipe_list=[session.init(anti_csrf="VIA_TOKEN"), emailpassword.init()],
+        recipe_list=[
+            session.init(anti_csrf="VIA_TOKEN"),
+            emailverification.init("OPTIONAL"),
+            emailpassword.init(),
+        ],
     )
     start_st()
 
@@ -765,14 +778,15 @@ async def test_the_email_verify_with_no_session_using_the_get_method(
     assert dict_response["message"] == "unauthorised"
 
 
-@mark.asyncio
 async def test_the_email_verify_api_with_valid_input_overriding_apis(
     driver_config_client: TestClient,
 ):
     token = None
     user_info_from_callback: Union[None, EVUser] = None
 
-    async def custom_f(_: User, email_verification_url_token: str, __: Dict[str, Any]):
+    async def custom_f(
+        _: EVUser, email_verification_url_token: str, __: Dict[str, Any]
+    ):
         nonlocal token
         token = email_verification_url_token.split("?token=")[1].split("&rid=")[0]
 
@@ -780,11 +794,14 @@ async def test_the_email_verify_api_with_valid_input_overriding_apis(
         temp = param.email_verify_post
 
         async def email_verify_post(
-            token: str, api_options: APIOptions, user_context: Dict[str, Any]
+            token: str,
+            session: Optional[SessionContainer],
+            api_options: APIOptions,
+            user_context: Dict[str, Any],
         ):
             nonlocal user_info_from_callback
 
-            response = await temp(token, api_options, user_context)
+            response = await temp(token, session, api_options, user_context)
 
             if isinstance(response, EmailVerifyPostOkResult):
                 user_info_from_callback = response.user
@@ -805,16 +822,12 @@ async def test_the_email_verify_api_with_valid_input_overriding_apis(
         framework="fastapi",
         recipe_list=[
             session.init(anti_csrf="VIA_TOKEN"),
-            emailpassword.init(
-                email_verification_feature=emailpassword.InputEmailVerificationConfig(
-                    create_and_send_custom_email=custom_f
-                ),
-                override=emailpassword.InputOverrideConfig(
-                    email_verification_feature=OverrideConfig(
-                        apis=apis_override_email_password
-                    )
-                ),
+            emailverification.init(
+                mode="REQUIRED",
+                create_and_send_custom_email=custom_f,
+                override=OverrideConfig(apis=apis_override_email_password),
             ),
+            emailpassword.init(),
         ],
     )
     start_st()
@@ -843,7 +856,9 @@ async def test_the_email_verify_api_with_valid_input_overriding_apis(
     assert token is not None
 
     response_3 = driver_config_client.post(
-        url="/auth/user/email/verify", json={"method": "token", "token": token}
+        url="/auth/user/email/verify",
+        json={"method": "token", "token": token},
+        headers={ANTI_CSRF_HEADER_KEY: response_1.headers.get("anti-csrf")},
     )
 
     dict_response = json.loads(response_3.text)
@@ -858,14 +873,15 @@ async def test_the_email_verify_api_with_valid_input_overriding_apis(
     assert user_info_from_callback.email == "test@gmail.com"  # type: ignore
 
 
-@mark.asyncio
 async def test_the_email_verify_api_with_valid_input_overriding_apis_throws_error(
     driver_config_client: TestClient,
 ):
     token = None
     user_info_from_callback: Union[None, EVUser] = None
 
-    async def custom_f(_: User, email_verification_url_token: str, __: Dict[str, Any]):
+    async def custom_f(
+        _: EVUser, email_verification_url_token: str, __: Dict[str, Any]
+    ):
         nonlocal token
         token = email_verification_url_token.split("?token=")[1].split("&rid=")[0]
 
@@ -873,11 +889,14 @@ async def test_the_email_verify_api_with_valid_input_overriding_apis_throws_erro
         temp = param.email_verify_post
 
         async def email_verify_post(
-            token: str, api_options: APIOptions, user_context: Dict[str, Any]
+            token: str,
+            session: Optional[SessionContainer],
+            api_options: APIOptions,
+            user_context: Dict[str, Any],
         ):
             nonlocal user_info_from_callback
 
-            response = await temp(token, api_options, user_context)
+            response = await temp(token, session, api_options, user_context)
 
             if isinstance(response, EmailVerifyPostOkResult):
                 user_info_from_callback = response.user
@@ -898,16 +917,14 @@ async def test_the_email_verify_api_with_valid_input_overriding_apis_throws_erro
         framework="fastapi",
         recipe_list=[
             session.init(anti_csrf="VIA_TOKEN"),
-            emailpassword.init(
-                email_verification_feature=emailpassword.InputEmailVerificationConfig(
-                    create_and_send_custom_email=custom_f
-                ),
-                override=emailpassword.InputOverrideConfig(
-                    email_verification_feature=OverrideConfig(
-                        apis=apis_override_email_password
-                    )
+            emailverification.init(
+                mode="REQUIRED",
+                create_and_send_custom_email=custom_f,
+                override=emailverification.InputOverrideConfig(
+                    apis=apis_override_email_password
                 ),
             ),
+            emailpassword.init(),
         ],
     )
     start_st()
@@ -936,7 +953,9 @@ async def test_the_email_verify_api_with_valid_input_overriding_apis_throws_erro
     assert token is not None
 
     response_3 = driver_config_client.post(
-        url="/auth/user/email/verify", json={"method": "token", "token": token}
+        url="/auth/user/email/verify",
+        json={"method": "token", "token": token},
+        headers={ANTI_CSRF_HEADER_KEY: response_1.headers.get("anti-csrf")},
     )
 
     dict_response = json.loads(response_3.text)
@@ -951,7 +970,6 @@ async def test_the_email_verify_api_with_valid_input_overriding_apis_throws_erro
     assert user_info_from_callback.email == "test@gmail.com"  # type: ignore
 
 
-@mark.asyncio
 async def test_the_generate_token_api_with_valid_input_and_then_remove_token(
     driver_config_client: TestClient,
 ):
@@ -964,7 +982,11 @@ async def test_the_generate_token_api_with_valid_input_and_then_remove_token(
             api_base_path="/auth",
         ),
         framework="fastapi",
-        recipe_list=[session.init(anti_csrf="VIA_TOKEN"), emailpassword.init()],
+        recipe_list=[
+            session.init(anti_csrf="VIA_TOKEN"),
+            emailverification.init("OPTIONAL"),
+            emailpassword.init(),
+        ],
     )
     start_st()
 
@@ -980,7 +1002,7 @@ async def test_the_generate_token_api_with_valid_input_and_then_remove_token(
     user_id = dict_response["user"]["id"]
 
     verify_token = await create_email_verification_token(user_id)
-    await revoke_email_verification_token(user_id)
+    await revoke_email_verification_tokens(user_id)
 
     if isinstance(verify_token, CreateEmailVerificationTokenOkResult):
         response = await verify_email_using_token(verify_token.token)
@@ -989,7 +1011,6 @@ async def test_the_generate_token_api_with_valid_input_and_then_remove_token(
     raise Exception("Test failed")
 
 
-@mark.asyncio
 async def test_the_generate_token_api_with_valid_input_verify_and_then_unverify_email(
     driver_config_client: TestClient,
 ):
@@ -1002,7 +1023,11 @@ async def test_the_generate_token_api_with_valid_input_verify_and_then_unverify_
             api_base_path="/auth",
         ),
         framework="fastapi",
-        recipe_list=[session.init(anti_csrf="VIA_TOKEN"), emailpassword.init()],
+        recipe_list=[
+            session.init(anti_csrf="VIA_TOKEN"),
+            emailverification.init(mode="OPTIONAL"),
+            emailpassword.init(),
+        ],
     )
     start_st()
 
@@ -1029,3 +1054,42 @@ async def test_the_generate_token_api_with_valid_input_verify_and_then_unverify_
         assert is_verified is False
         return
     raise Exception("Test failed")
+
+
+@min_api_version("2.11")
+async def test_email_verify_with_deleted_user(driver_config_client: TestClient):
+    async def custom_f(_: EVUser, __: str, ___: Optional[Dict[str, Any]]):
+        return None
+
+    st_args = get_st_init_args(
+        [
+            emailpassword.init(),
+            emailverification.init("OPTIONAL", create_and_send_custom_email=custom_f),
+            session.init(),
+        ]
+    )
+    init(**st_args)
+    start_st()
+
+    res = sign_up_request(driver_config_client, "test@gmail.com", "testPass123")
+    dict_response = json.loads(res.text)
+
+    assert res.status_code == 200
+    assert dict_response["status"] == "OK"
+
+    user_id = dict_response["user"]["id"]
+    cookies = extract_all_cookies(res)
+
+    await delete_user(user_id)
+
+    response = email_verify_token_request(
+        driver_config_client,
+        cookies["sAccessToken"]["value"],
+        cookies["sIdRefreshToken"]["value"],
+        res.headers.get("anti-csrf"),  # type: ignore
+        user_id,
+    )
+    dict_response = json.loads(response.text)
+
+    assert response.status_code == 401
+    assert dict_response == {"message": "unauthorised"}
